AnalyzeFileInput class

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

AnalyzeFileInput({required String path, required String workingDirectory, List<ContentChange>? changes})
const
AnalyzeFileInput.fromJson(Map json)
factory

Properties

changes List<ContentChange>?
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type AnalyzeInputType
no setteroverride
workingDirectory String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited