ChangeDetails class

Annotations
  • @JsonSerializable.new()

Constructors

ChangeDetails({required String label, String? description, bool? needsConfirmation = false})
const
ChangeDetails.fromJson(Map json)
factory

Properties

description String?
A human-readable string which is rendered less prominent in the user interface.
final
hashCode int
The hash code for this object.
no setterinherited
label String
A human-readable string describing the actual change. The string is rendered prominent in the user interface.
final
needsConfirmation bool?
A flag which indicates that user confirmation is needed before applying the change.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited