CodeAction class

Implementers
Annotations
  • @JsonSerializable.new(constructor: '_')

Constructors

CodeAction({required String title, List<CodeActionKind>? kinds, ({String reason})? disabled, bool? isPreferred, List<DocumentEdit> steps = const []})
const
CodeAction.fromJson(Map json)
factory

Properties

disabled → ({String reason})?
Marks that the code action cannot currently be applied.
final
hashCode int
The hash code for this object.
no setterinherited
isPreferred bool?
Marks this as a preferred action. Preferred actions are used by the auto fix command and can be targeted by keybindings.
final
kinds List<CodeActionKind>?
The kinds of the code action.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<DocumentEdit>
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
A short, human-readable, title for this code action.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited