CreateFile class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

CreateFile({required String path, required String content, ModifyFileOptions? options, ChangeDetails? details})
const
CreateFile.fromJson(Map json)
factory

Properties

content String
final
details ChangeDetails?
final
hashCode int
The hash code for this object.
no setterinherited
kind DocumentEditKind
no setteroverride
options ModifyFileOptions?
final
path String
The path of the file to create
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited