DeleteFile class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

DeleteFile({required String path, DeleteFileOptions? options, ChangeDetails? details})
const
DeleteFile.fromJson(Map json)
factory

Properties

details ChangeDetails?
final
hashCode int
The hash code for this object.
no setterinherited
kind DocumentEditKind
no setteroverride
options DeleteFileOptions?
final
path String
The path of the file to delete
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited