FormatFile class

Formats a Dart file.

This operation is exclusively utilized by the lint_kit fix command. In all other scenarios, such as IDE quick fixes, it performs no action.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

FormatFile(String path)
const
FormatFile.fromJson(Map json)
factory

Properties

details → Never
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
kind DocumentEditKind
no setteroverride
path String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited