IgnoreForFileCodeAction class

Inheritance

Constructors

IgnoreForFileCodeAction({required String lintCode, List<DocumentEdit> steps = const []})
IgnoreForFileCodeAction.from(Lint lint, {Iterable<String> otherIgnoreCodes = const []})
factory

Properties

disabled → ({String reason})?
Marks that the code action cannot currently be applied.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isPreferred bool?
Marks this as a preferred action. Preferred actions are used by the auto fix command and can be targeted by keybindings.
finalinherited
kinds List<CodeActionKind>?
The kinds of the code action.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<DocumentEdit>
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
A short, human-readable, title for this code action.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

title_(String lintCode) String