Lint class

Implemented types
Annotations
  • @JsonSerializable.new(constructor: '_')

Constructors

Lint({required Range range, required String code, required String message, required String path, LintSeverity severity = LintSeverity.warning, List<LintTag> tags = const [], List<CodeAction> actions = const []})
const
Lint.fromJson(Map json)
factory

Properties

actions List<CodeAction>
final
code String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
path String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
range Range
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity LintSeverity
final
source String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tags List<LintTag>
final
type MessageType
no setteroverride

Methods

addIgnoreActions(List<String> contentLines) Lint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideWith({LintSeverity? severity, String? source}) Lint
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited