LintKitRule class abstract interface

Properties

enabled bool
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
options Map<String, dynamic>
no setter
package String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity LintSeverity?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited