ModifyContent class

Inheritance
Annotations
  • @JsonSerializable.new(constructor: '_')

Constructors

ModifyContent({required String path, required Range range, required String newText, ChangeDetails? details})
const
ModifyContent.delete({required String path, required Range range, ChangeDetails? details})
const
ModifyContent.fromJson(Map json)
factory
ModifyContent.snippet({required String path, required Range range, required String newText, ChangeDetails? details})
const

Properties

details ChangeDetails?
final
format InsertTextFormat
final
hashCode int
The hash code for this object.
no setterinherited
kind DocumentEditKind
no setteroverride
newText String
final
path String
The path of the file to create
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
range Range
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited