Range class

Annotations
  • @JsonSerializable.new()

Constructors

Range({required Position start, required Position end})
const
Range.entireLine(int line)
Range.fromJson(Map<String, dynamic> json)
factory
Range.fromPosition(Position position)
const
Range.startOfLine(int line)

Properties

end Position
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Position
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

intersects(Range range) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited