ServerNotificationProgress class

Inheritance
Annotations
  • @JsonSerializable.new(constructor: '_')

Constructors

ServerNotificationProgress({required String id, required String title, required String workspace, String? message, Duration? timeout})
const
ServerNotificationProgress.fromJson(Map<String, dynamic> json)
factory

Properties

completeMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
isComplete bool
final
message String
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timeout Duration?
final
title String
final
type ServerNotificationType
no setteroverride
workspace String
finalinherited

Methods

complete([String? message]) ServerNotificationProgress
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override
update(String message, {Duration? timeout}) ServerNotificationProgress

Operators

operator ==(Object other) bool
The equality operator.
inherited