ServerNotificationTrigger class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ServerNotificationTrigger({required NotificationTriggers trigger, required String id, required String workspace})
const
ServerNotificationTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
message String
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
trigger NotificationTriggers
final
type ServerNotificationType
no setteroverride
workspace String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited