CodeAction class
- Implementers
- Annotations
-
- @JsonSerializable.new(constructor: '_')
Properties
-
disabled
→ ({String reason})?
-
Marks that the code action cannot currently be applied.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isPreferred
→ bool?
-
Marks this as a preferred action. Preferred actions are used by the
auto fix command and can be targeted by keybindings.
final
-
kinds
→ List<CodeActionKind>?
-
The kinds of the code action.
final
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<DocumentEdit>
-
final
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
title
→ String
-
A short, human-readable, title for this code action.
final