disabled property
Marks that the code action cannot currently be applied.
Clients should follow the following guidelines regarding disabled code actions:
-
Disabled code actions are not shown in automatic lightbulbs code action menus.
-
Disabled actions are shown as faded out in the code action menu when the user requests a more specific type of code action, such as refactorings.
-
If the user has a keybinding that auto applies a code action and only disabled code actions are returned, the client should show the user an error message with
reasonin the editor.
Implementation
@JsonKey(includeIfNull: false)
final ({String reason})? disabled;