isPreferred property
Marks this as a preferred action. Preferred actions are used by the auto fix command and can be targeted by keybindings.
A quick fix should be marked preferred if it properly addresses the underlying error. A refactoring should be marked preferred if it is the most reasonable choice of actions to take.
Implementation
@JsonKey(includeIfNull: false)
final bool? isPreferred;