CodeActionKind enum
A set of predefined code action kinds
Values
- empty → const CodeActionKind
-
Empty kind.
const CodeActionKind('') - quickfix → const CodeActionKind
-
Base kind for quickfix actions: 'quickfix'
const CodeActionKind('quickfix') - refactor → const CodeActionKind
-
Base kind for refactoring actions: 'refactor'
const CodeActionKind('refactor') - refactorExtract → const CodeActionKind
-
Base kind for refactoring extraction actions: 'refactor.extract'
Example extract actions:
- Extract method
- Extract function
- Extract variable
- Extract interface from class
- ...
const CodeActionKind('refactor.extract') - refactorInline → const CodeActionKind
-
Base kind for refactoring inline actions: 'refactor.inline'
Example inline actions:
- Inline function
- Inline variable
- Inline constant
- ...
const CodeActionKind('refactor.inline') - refactorRewrite → const CodeActionKind
-
Base kind for refactoring rewrite actions: 'refactor.rewrite'
Example rewrite actions:
- Convert Dart function to class
- Add or remove parameter
- Encapsulate field
- Make method static
- Move method to base class
- ...
const CodeActionKind('refactor.rewrite') - source → const CodeActionKind
-
Base kind for source actions:
sourceSource code actions apply to the entire file.
const CodeActionKind('source') - fixAll → const CodeActionKind
-
Base kind for auto-fix source actions:
source.fixAll.Fix all actions automatically fix errors that have a clear fix that do not require user input. They should not suppress errors or perform unsafe fixes such as generating new types or classes.
const CodeActionKind('source.fixAll') - organizeImports → const CodeActionKind
-
Base kind for an organize imports source action:
source.organizeImportsconst CodeActionKind('source.organizeImports')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CodeActionKind> - A constant List of the values in this enum, in order of their declaration.