RenameFile class
- Inheritance
-
- Object
- DocumentEdit
- RenameFile
- Annotations
-
- @JsonSerializable.new()
Constructors
- RenameFile({required String newPath, required String oldPath, ModifyFileOptions? options, ChangeDetails? details})
-
const
- RenameFile.fromJson(Map json)
-
factory
Properties
- details → ChangeDetails?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → DocumentEditKind
-
no setteroverride
- newPath → String
-
The new path of the file
final
- oldPath → String
-
The old path of the file
final
- options → ModifyFileOptions?
-
final
- path → Never
-
no setteroverride
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited