ServerNotificationMessage class
- Inheritance
-
- Object
- ServerNotification
- ServerNotificationMessage
- Implementers
- Annotations
-
- @JsonSerializable.new()
Constructors
- ServerNotificationMessage({required String id, required String message, required String workspace})
-
const
-
ServerNotificationMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- message → String
-
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → ServerNotificationType
-
no setteroverride
- workspace → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited